%global page_size %(getconf PAGESIZE)

Summary:        General-purpose scalable concurrent malloc implementation
Name:           jemalloc
Version:        5.3.0
Release:        5%{?dist}

License:        BSD
URL:            http://jemalloc.net/
Source0:        https://github.com/jemalloc/%{name}/releases/download/%{version}/%{name}-%{version}.tar.bz2

BuildRequires:  gcc make perl-generators
BuildRequires:  /usr/bin/xsltproc
BuildRequires:  valgrind-devel

%description
jemalloc is a general purpose malloc(3) implementation that emphasizes
fragmentation avoidance and scalable concurrency support. jemalloc first
came into use as the FreeBSD libc allocator in 2005, and since then it
has found its way into numerous applications that rely on its predictable
behavior. In 2010 jemalloc development efforts broadened to include developer
support features such as heap profiling and extensive monitoring/tuning hooks.
Modern jemalloc releases continue to be integrated back into FreeBSD, and
therefore versatility remains critical. Ongoing development efforts trend
toward making jemalloc among the best allocators for a broad range of demanding
applications, and eliminating/mitigating weaknesses that have practical
repercussions for real world applications.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

# Temporary avoidance for 64 page size
%if %{?page_size} == 65536
sed -i '/test\/unit\/psset/d' Makefile.in
%endif

%ifarch x86_64
%define lg_page --with-lg-page=12
%endif

%ifarch ppc64le aarch64
%define lg_page --with-lg-page=16
%endif

%ifarch aarch64
%define disable_thp --disable-thp
%endif


%build
%configure %{?disable_thp} %{?lg_page}
%make_build


%check
make %{?_smp_mflags} check


%install
%make_install
rm %{buildroot}%{_datadir}/doc/%{name}/jemalloc.html

find %{buildroot}%{_libdir}/ -name '*.a' -exec rm -vf {} ';'

%files
%license COPYING
%doc README VERSION
%doc doc/jemalloc.html
%{_bindir}/jemalloc.sh
%{_libdir}/libjemalloc.so.*

%files devel
%{_bindir}/jeprof
%{_bindir}/jemalloc-config
%{_libdir}/pkgconfig/jemalloc.pc
%{_libdir}/libjemalloc.so
%{_includedir}/jemalloc
%{_mandir}/man3/jemalloc.3*


%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.3.0-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.3.0-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.3.0-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Feb 1 2023 Shuo Wang <abushwang@tencent.com> - 5.3.0-2
- Temporary avoidance for 64 page size

* Tue Dec 6 2022 cunshunxia <cunshunxia@tencent.com> - 5.3.0-1
- initial build
